# RuleQueryBody

Body describes constraints on the request. It helps to prevent users from modifying special fields(e.g. userid) in the body to gain extra access rights in the system. The format of the body(e.g. JSON) is specified below with the restriction. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**json** | [**list[RuleQueryBodyJSON]**](RuleQueryBodyJSON.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


